**********************
Working with Processes
**********************

.. currentmodule:: gruvi

.. attribute:: gruvi.PIPE = ...

.. attribute:: gruvi.DEVNULL = ...

.. autoclass:: gruvi.Process
    :members:
